@@ -1,12 +1,18 @@
+"""idmtools json configured task.
+
+Copyright 2021, Bill & Melinda Gates Foundation. All rights reserved.
+"""
 import json
 from dataclasses import dataclass, field, fields
 from functools import partial
 from logging import getLogger, DEBUG
-from typing import Union, Dict, Any, List, Optional, Type
+from typing import Union, Dict, Any, List, Optional, Type, TYPE_CHECKING
 from idmtools.assets import Asset, AssetCollection
 from idmtools.entities.itask import ITask
 from idmtools.entities.simulation import Simulation
 from idmtools.registry.task_specification import TaskSpecification
+if TYPE_CHECKING:  # pragma: no cover
+    from idmtools.entities.iplatform import IPlatform
 
 TJSONConfigKeyType = Union[str, int, float]
 TJSONConfigValueType = Union[str, int, float, Dict[TJSONConfigKeyType, Any]]
@@ -18,7 +24,7 @@ user_logger = getLogger('user')
 @dataclass
 class JSONConfiguredTask(ITask):
     """
-    Defines an extensible simple task that implements functionality through optional supplied use hooks
+    Defines an extensible simple task that implements functionality through optional supplied use hooks.
     """
 
     # Note: large amounts of parameters will increase size of metadata
@@ -28,13 +34,14 @@ class JSONConfiguredTask(ITask):
     config_file_name: str = field(default="config.json", metadata={"md": True})
     # is the config file a common asset or a transient. We default ot transient
     is_config_common: bool = field(default=False)
-    command_line_argument: str = field(default=None)
+    configfile_argument: str = field(default=None)
     # If command_line_argument is set, defines if we pass the filename after the argument
     # for example, if the argument is --config and the config file name is config.json we would run the command as
     # cmd --config config.json
-    command_line_argument_no_filename: bool = field(default=True)
+    command_line_argument_no_filename: bool = field(default=False)
 
     def __post_init__(self):
+        """Constructor."""
         super().__post_init__()
         if self.parameters is not None and self.envelope is not None and self.envelope in self.parameters:
             logger.debug(f'Loading parameters from envelope: {self.envelope}')
@@ -42,7 +49,7 @@ class JSONConfiguredTask(ITask):
 
     def gather_common_assets(self) -> AssetCollection:
         """
-        Gather assets common across an Experiment(Set of Simulations)
+        Gather assets common across an Experiment(Set of Simulations).
 
         Returns:
             Common AssetCollection
@@ -53,7 +60,7 @@ class JSONConfiguredTask(ITask):
 
     def gather_transient_assets(self) -> AssetCollection:
         """
-        Gather assets that are unique to this simulation/worktiem
+        Gather assets that are unique to this simulation/worktiem.
 
         Returns:
             Simulation/workitem level AssetCollection
@@ -63,7 +70,7 @@ class JSONConfiguredTask(ITask):
 
     def __dump_config(self, assets) -> None:
         """
-        Writes the configuration out to asset
+        Writes the configuration out to asset.
 
         Args:
             assets: Asset to add configuration too
@@ -73,30 +80,31 @@ class JSONConfiguredTask(ITask):
         """
         if self.config_file_name is not None:
             params = {self.envelope: self.parameters} if self.envelope else self.parameters
-            self._task_log.info('Adding JSON Configured File %s', self.config_file_name)
             if logger.isEnabledFor(DEBUG):
-                logger.info(f'Generating {self.config_file_name} as an asset from JSONConfiguredTask')
-                self._task_log.debug('Writing Config %s', json.dumps(params))
+                logger.debug('Adding JSON Configured File %s', self.config_file_name)
+                logger.debug(f'Generating {self.config_file_name} as an asset from JSONConfiguredTask')
+                logger.debug('Writing Config %s', json.dumps(params))
             assets.add_or_replace_asset(Asset(filename=self.config_file_name, content=json.dumps(params)))
 
     def set_parameter(self, key: TJSONConfigKeyType, value: TJSONConfigValueType):
         """
-        Update a parameter. The type hinting encourages JSON supported types
+        Update a parameter. The type hinting encourages JSON supported types.
 
         Args:
             key: Config
             value:
 
         Returns:
-
+            Tags to be defined on the simulation/workitem
         """
-        self._task_log.info('Setting parameter %s to %s', key, str(value))
+        if logger.isEnabledFor(DEBUG):
+            logger.info('Setting parameter %s to %s', key, str(value))
         self.parameters[key] = value
         return {key: value}
 
     def get_parameter(self, key: TJSONConfigKeyType) -> TJSONConfigValueType:
         """
-        Returns a parameter value
+        Returns a parameter value.
 
         Args:
             key: Key of parameter
@@ -110,23 +118,26 @@ class JSONConfiguredTask(ITask):
 
     def update_parameters(self, values: Dict[TJSONConfigKeyType, TJSONConfigValueType]):
         """
-        Perform bulk update from another dictionary
+        Perform bulk update from another dictionary.
 
         Args:
-            values:
+            values: Values to update as dictionaryy
 
         Returns:
-
+            Values
         """
-        for k, p in values.items():
-            self._task_log.info('Setting parameter %s to %s', k, str(p))
+        if logger.isEnabledFor(DEBUG):
+            for k, p in values.items():
+                logger.debug('Setting parameter %s to %s', k, str(p))
         self.parameters.update(values)
         return values
 
     def reload_from_simulation(self, simulation: 'Simulation', config_file_name: Optional[str] = None,
                                envelope: Optional[str] = None, **kwargs):  # noqa: F821
         """
-        Reload from Simulation. To do this, the process is
+        Reload from Simulation.
+
+        To do this, the process is
 
          1. First check for a configfile name from arguments, then tags, or the default name
          2. Load the json config file
@@ -151,13 +162,14 @@ class JSONConfiguredTask(ITask):
 
     def __find_config(self, simulation: Simulation, config_file_name: str = None) -> Dict[str, Any]:
         """
+        Used to rebuild configuration using simulation data that has been ran.
 
         Args:
-            simulation:
-            config_file_name:
+            simulation: Simulation to load from
+            config_file_name: Config file name
 
         Returns:
-
+            Config reloaded
         """
         # find the ocnfig
         if config_file_name:
@@ -177,7 +189,7 @@ class JSONConfiguredTask(ITask):
                         config = json.loads(config.decode('utf-8'))
             new_assets = []
             # filter our config from the simulation
-            for i, asset in enumerate(simulation.assets.assets):
+            for _i, asset in enumerate(simulation.assets.assets):
                 if asset.filename != cfn:
                     new_assets.append(asset)
             simulation.assets.assets = new_assets
@@ -199,7 +211,17 @@ class JSONConfiguredTask(ITask):
             self.transient_assets = nw
         return config
 
-    def pre_creation(self, parent: Union['Simulation', 'WorkflowItem']):  # noqa: F821
+    def pre_creation(self, parent: Union['Simulation', 'WorkflowItem'], platform: 'IPlatform'):  # noqa: F821
+        """
+        Pre-creation. For JSONConfiguredTask, we finalize our configuration file and command line here.
+
+        Args:
+            parent: Parent of task
+            platform: Platform task is being created on
+
+        Returns:
+            None
+        """
         defaults = [x for x in fields(JSONConfiguredTask) if x.name == "config_file_name"][0].default
 
         if self.config_file_name != defaults:
@@ -210,34 +232,62 @@ class JSONConfiguredTask(ITask):
             logger.info('Found envelope name. Adding tag envelope')
             parent.tags['task_envelope'] = self.envelope
         # Ensure our command line argument is added if configured
-        if self.command_line_argument:
+        if self.configfile_argument:
             logger.debug('Adding command_line_argument to command')
-            if self.command_line_argument not in self.command.arguments:
+            if self.configfile_argument not in self.command.arguments:
                 # check if we should add filename with arg?
                 if self.command_line_argument_no_filename:
-                    self.command.add_argument(self.command_line_argument)
+                    self.command.add_argument(self.configfile_argument)
                 else:
-                    self.command.add_option(self.command_line_argument, self.config_file_name)
+                    self.command.add_argument(self.configfile_argument)
+                    self.command.add_argument(self.config_file_name)
 
     def __repr__(self):
+        """String version of task Prints config filename and parameters."""
         return f"<JSONConfiguredTask config:{self.config_file_name} parameters: {self.parameters}"
 
     @staticmethod
     def set_parameter_sweep_callback(simulation: Simulation, param: str, value: Any) -> Dict[str, Any]:
+        """
+        Performs a callback with a parameter and a value. Most likely users want to use set_parameter_partial instead of this method.
+
+        Args:
+            simulation: Simulation object
+            param: Param name
+            value: Value to set
+
+        Returns:
+            Tags to add to simulation
+        """
         if not hasattr(simulation.task, 'set_parameter'):
             raise ValueError("update_task_with_set_parameter can only be used on tasks with a set_parameter")
         return simulation.task.set_parameter(param, value)
 
     @classmethod
     def set_parameter_partial(cls, parameter: str):
+        """
+        Callback to be used when sweeping with a json configured model.
+
+        Args:
+            parameter: Param name
+
+        Returns:
+            Partial setting a specific parameter
+
+        Notes:
+            - TODO Reference some examples code here
+        """
         return partial(cls.set_parameter_sweep_callback, param=parameter)
 
 
 class JSONConfiguredTaskSpecification(TaskSpecification):
+    """
+    JSONConfiguredTaskSpecification defines the plugin specs for JSONConfiguredTask.
+    """
 
     def get(self, configuration: dict) -> JSONConfiguredTask:
         """
-        Get instance of JSONConfiguredTask with configuration specified
+        Get instance of JSONConfiguredTask with configuration specified.
 
         Args:
             configuration: Configuration for configuration
@@ -249,7 +299,7 @@ class JSONConfiguredTaskSpecification(TaskSpecification):
 
     def get_description(self) -> str:
         """
-        Get description for plugin
+        Get description for plugin.
 
         Returns:
             Description of plugin
@@ -258,7 +308,7 @@ class JSONConfiguredTaskSpecification(TaskSpecification):
 
     def get_example_urls(self) -> List[str]:
         """
-        Get list of urls with examples for JSONConfiguredTask
+        Get list of urls with examples for JSONConfiguredTask.
 
         Returns:
             List of urls that point to examples relating to JSONConfiguredTask
@@ -269,9 +319,19 @@ class JSONConfiguredTaskSpecification(TaskSpecification):
 
     def get_type(self) -> Type[JSONConfiguredTask]:
         """
-        Get task type provided by plugin
+        Get task type provided by plugin.
 
         Returns:
             JSONConfiguredTask
         """
         return JSONConfiguredTask
+
+    def get_version(self) -> str:
+        """
+        Returns the version of the plugin.
+
+        Returns:
+            Plugin Version
+        """
+        from idmtools_models import __version__
+        return __version__
