@@ -1,5 +1,9 @@
+"""idmtools json configured python task.
+
+Copyright 2021, Bill & Melinda Gates Foundation. All rights reserved.
+"""
 from dataclasses import dataclass, field
-from typing import Optional, Type, Union
+from typing import Optional, Type, Union, TYPE_CHECKING
 from idmtools.assets import AssetCollection
 from idmtools.entities.iworkflow_item import IWorkflowItem
 from idmtools.entities.simulation import Simulation
@@ -7,28 +11,41 @@ from idmtools.registry.task_specification import TaskSpecification
 from idmtools_models.json_configured_task import JSONConfiguredTask
 from idmtools_models.python.python_task import PythonTask
 
+if TYPE_CHECKING:  # pragma: no cover
+    from idmtools.entities.iplatform import IPlatform
+
 
 @dataclass
 class JSONConfiguredPythonTask(JSONConfiguredTask, PythonTask):
+    """
+    JSONConfiguredPythonTask combines JSONConfiguredTask and PythonTask.
+
+    Notes:
+        - TODO Add examples here
+
+    See Also:
+        :class:`idmtools_models.json_configured_task.JSONConfiguredTask`
+        :class:`idmtools_models.python.python_task.PythonTask`
+    """
     configfile_argument: Optional[str] = field(default="--config")
 
     def __post_init__(self):
-        super().__post_init__()
-        if self.configfile_argument is not None:
-            self.command.add_option(self.configfile_argument, self.config_file_name)
+        """Constructor."""
+        JSONConfiguredTask.__post_init__(self)
+        PythonTask.__post_init__(self)
 
     def gather_common_assets(self):
         """
-        Return the common assets for a JSON Configured Task
-        a derived class
-        Returns:
+        Return the common assets for a JSON Configured Task a derived class.
 
+        Returns:
+            Assets
         """
         return PythonTask.gather_common_assets(self)
 
     def gather_transient_assets(self) -> AssetCollection:
         """
-        Get Transient assets. This should general be the config.json
+        Get Transient assets. This should general be the config.json.
 
         Returns:
             Transient assets
@@ -37,7 +54,7 @@ class JSONConfiguredPythonTask(JSONConfiguredTask, PythonTask):
 
     def reload_from_simulation(self, simulation: Simulation, **kwargs):
         """
-        Reload the task from a simulation
+        Reload the task from a simulation.
 
         Args:
             simulation: Simulation to reload from
@@ -53,12 +70,13 @@ class JSONConfiguredPythonTask(JSONConfiguredTask, PythonTask):
         JSONConfiguredTask.reload_from_simulation(self, simulation, **kwargs)
         PythonTask.reload_from_simulation(self, simulation, **kwargs)
 
-    def pre_creation(self, parent: Union[Simulation, IWorkflowItem]):
+    def pre_creation(self, parent: Union[Simulation, IWorkflowItem], platform: 'IPlatform'):
         """
-        Pre-creation
+        Pre-creation.
 
         Args:
-            parent:
+            parent: Parent of task
+            platform: Platform Python Script is being executed on
 
         Returns:
             None
@@ -66,31 +84,38 @@ class JSONConfiguredPythonTask(JSONConfiguredTask, PythonTask):
             :meth:`idmtools_models.json_configured_task.JSONConfiguredTask.pre_creation`
             :meth:`idmtools_models.python.python_task.PythonTask.pre_creation`
         """
-        JSONConfiguredTask.pre_creation(self, parent)
-        PythonTask.pre_creation(self, parent)
+        PythonTask.pre_creation(self, parent, platform)
+        JSONConfiguredTask.pre_creation(self, parent, platform)
 
-    def post_creation(self, parent: Union[Simulation, IWorkflowItem]):
+    def post_creation(self, parent: Union[Simulation, IWorkflowItem], platform: 'IPlatform'):
         """
-        Post-creation
+        Post-creation.
+
+        For us, we proxy the underlying JSONConfiguredTask and PythonTask/
 
         Args:
             parent: Parent
+            platform: Platform Python Script is being executed on
 
         Returns:
+            None
 
         See Also
             :meth:`idmtools_models.json_configured_task.JSONConfiguredTask.post_creation`
             :meth:`idmtools_models.python.python_task.PythonTask.post_creation`
         """
-        JSONConfiguredTask.post_creation(self, parent)
-        PythonTask.post_creation(self, parent)
+        JSONConfiguredTask.post_creation(self, parent, platform)
+        PythonTask.post_creation(self, parent, platform)
 
 
 class JSONConfiguredPythonTaskSpecification(TaskSpecification):
+    """
+    JSONConfiguredPythonTaskSpecification provides the plugin info for JSONConfiguredPythonTask.
+    """
 
     def get(self, configuration: dict) -> JSONConfiguredPythonTask:
         """
-        Get  instance of JSONConfiguredPythonTask with configuration
+        Get  instance of JSONConfiguredPythonTask with configuration.
 
         Args:
             configuration: Configuration for task
@@ -102,7 +127,7 @@ class JSONConfiguredPythonTaskSpecification(TaskSpecification):
 
     def get_description(self) -> str:
         """
-        Get description for plugin
+        Get description for plugin.
 
         Returns:
             Plugin Description
@@ -111,9 +136,19 @@ class JSONConfiguredPythonTaskSpecification(TaskSpecification):
 
     def get_type(self) -> Type[JSONConfiguredPythonTask]:
         """
-        Get Type for Plugin
+        Get Type for Plugin.
 
         Returns:
             JSONConfiguredPythonTask
         """
         return JSONConfiguredPythonTask
+
+    def get_version(self) -> str:
+        """
+        Returns the version of the plugin.
+
+        Returns:
+            Plugin Version
+        """
+        from idmtools_models import __version__
+        return __version__
